==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/SelectAllCheckboxChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectAllCheckboxChangedEventArgsDescription } from "./SelectAllCheckboxChangedEventArgsDescription";
/**
 * @hidden
 */
var SelectAllCheckboxChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SelectAllCheckboxChangedEventArgsDescriptionMetadata, _super);
    function SelectAllCheckboxChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SelectAllCheckboxChangedEventArgsDescriptionMetadata.b = function (a) {
        if (SelectAllCheckboxChangedEventArgsDescriptionMetadata.a == null) {
            SelectAllCheckboxChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SelectAllCheckboxChangedEventArgsDescriptionMetadata.c(SelectAllCheckboxChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(SelectAllCheckboxChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(SelectAllCheckboxChangedEventArgsDescriptionMetadata.a);
    };
    SelectAllCheckboxChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("IsChecked", "Boolean");
    };
    SelectAllCheckboxChangedEventArgsDescriptionMetadata.d = function (a) {
        SelectAllCheckboxChangedEventArgsDescriptionMetadata.b(a);
        a.ac("SelectAllCheckboxChangedEventArgs", function () { return new SelectAllCheckboxChangedEventArgsDescription(); });
        a.ab("SelectAllCheckboxChangedEventArgs", SelectAllCheckboxChangedEventArgsDescriptionMetadata.a);
    };
    SelectAllCheckboxChangedEventArgsDescriptionMetadata.$t = markType(SelectAllCheckboxChangedEventArgsDescriptionMetadata, 'SelectAllCheckboxChangedEventArgsDescriptionMetadata');
    SelectAllCheckboxChangedEventArgsDescriptionMetadata.a = null;
    return SelectAllCheckboxChangedEventArgsDescriptionMetadata;
}(Base));
export { SelectAllCheckboxChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/SelectAllCheckboxChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectAllCheckboxChangedEventArgsDescription } from "./SelectAllCheckboxChangedEventArgsDescription";
/**
 * @hidden
 */
var SelectAllCheckboxChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SelectAllCheckboxChangedEventArgsDescriptionMetadata, _super);
    function SelectAllCheckboxChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SelectAllCheckboxChangedEventArgsDescriptionMetadata.b = function (a) {
        if (SelectAllCheckboxChangedEventArgsDescriptionMetadata.a == null) {
            SelectAllCheckboxChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SelectAllCheckboxChangedEventArgsDescriptionMetadata.c(SelectAllCheckboxChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(SelectAllCheckboxChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(SelectAllCheckboxChangedEventArgsDescriptionMetadata.a);
    };
    SelectAllCheckboxChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("IsChecked", "Boolean");
    };
    SelectAllCheckboxChangedEventArgsDescriptionMetadata.d = function (a) {
        SelectAllCheckboxChangedEventArgsDescriptionMetadata.b(a);
        a.ae("SelectAllCheckboxChangedEventArgs", function () { return new SelectAllCheckboxChangedEventArgsDescription(); });
        a.ad("SelectAllCheckboxChangedEventArgs", SelectAllCheckboxChangedEventArgsDescriptionMetadata.a);
    };
    SelectAllCheckboxChangedEventArgsDescriptionMetadata.$t = markType(SelectAllCheckboxChangedEventArgsDescriptionMetadata, 'SelectAllCheckboxChangedEventArgsDescriptionMetadata');
    SelectAllCheckboxChangedEventArgsDescriptionMetadata.a = null;
    return SelectAllCheckboxChangedEventArgsDescriptionMetadata;
}(Base));
export { SelectAllCheckboxChangedEventArgsDescriptionMetadata };
